# -*- coding: utf-8 -*-
# copyright 2023 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
# contact https://www.logilab.fr -- mailto:contact@logilab.fr
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Lesser General Public License as published by the Free
# Software Foundation, either version 2.1 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
# details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program. If not, see <https://www.gnu.org/licenses/>.

"""cubicweb-rodolf schema"""

from yams.buildobjs import (
    Boolean,
    EntityType,
    String,
    SubjectRelation,
)
from cubicweb.schema import WorkflowableEntityType


class ImportProcedure(EntityType):
    name = String()
    virtuoso_url = String(required=True)
    virtuoso_user = String(required=True, default="dba")
    virtuoso_password = String(required=True)
    ontology_file = SubjectRelation("File", cardinality="??", inlined=True)
    shacl_files = SubjectRelation("File", cardinality="**")
    import_recipes = SubjectRelation("ImportRecipe", cardinality="*?")
    activated = Boolean(required=True, default=True)


class DataService(EntityType):
    name = String(required=True)
    data_url = String(required=True, unique=True)
    refresh_period = String(
        required=True,
        vocabulary=["daily", "weekly", "monthly"],
        default="daily",
    )
    description = String()


class ImportRecipe(EntityType):
    name = String(required=True)
    dataservice = SubjectRelation("DataService", cardinality="1*")
    graph_uri = String()
    process_type = String(
        required=True,
        vocabulary=["default", "default-dryrun"],
        default="default",
    )


class ImportProcess(WorkflowableEntityType):
    import_recipe = SubjectRelation("ImportRecipe", cardinality="1*", inlined=True)
    import_procedure = SubjectRelation(
        "ImportProcedure", cardinality="1*", inlined=True
    )
    rq_task = SubjectRelation("RqTask", cardinality="11", inlined=True)
    has_input_dataset = SubjectRelation("File", cardinality="??", inlined=True)
    has_output_dataset = SubjectRelation("File", cardinality="??", inlined=True)
    import_report = SubjectRelation("File", cardinality="??", inlined=True)
    shacl_valid = Boolean()
    shacl_report = SubjectRelation("File", cardinality="??", inlined=True)
