"use client";

import {
  Alert,
  Box,
  Card,
  CardActions,
  CardContent,
  Container,
  Stack,
  TextField,
  Typography,
} from "@mui/material";
import LoginIcon from "@mui/icons-material/Login";
import { Controller, SubmitHandler, useForm } from "react-hook-form";
import { useRouter } from "next/navigation";
import { useState } from "react";
import { LoadingButton } from "@mui/lab";
import { useApiLogin } from "@/api/cubicweb";

interface FormData {
  login: string;
  password: string;
}

export default function Login() {
  const {
    handleSubmit,
    setError,
    formState: { errors },
    control,
  } = useForm<FormData>();
  const router = useRouter();
  const [loading, setLoading] = useState(false);
  const login = useApiLogin();

  const onSubmit: SubmitHandler<FormData> = async (data) => {
    setLoading(true);
    const result = await login(data.login, data.password);
    setLoading(false);
    if (result) {
      router.push("/");
    } else {
      setError("root", { message: "Identifiant ou mot de passe invalide" });
    }
  };

  return (
    <Container>
      <Stack spacing={3} alignItems={"center"} paddingTop={5}>
        <Stack spacing={1} alignItems={"center"}>
          <Typography variant="h4">Bienvenue sur Rodolf</Typography>
          <Typography variant="subtitle1">
            Merci de vous connecter pour continuer
          </Typography>
        </Stack>
        <Box minWidth={300} width={"50%"}>
          <Card>
            <form onSubmit={handleSubmit(onSubmit)}>
              <CardContent>
                <Stack spacing={2}>
                  {errors.root ? (
                    <Alert severity="error">{errors.root?.message}</Alert>
                  ) : null}
                  <Controller
                    name="login"
                    control={control}
                    rules={{ required: true }}
                    render={({ field, fieldState: { error } }) => (
                      <TextField
                        label="Identifiant"
                        disabled={loading}
                        {...field}
                        error={error !== undefined}
                        helperText={
                          error?.type === "required"
                            ? "Champ requis"
                            : error?.message
                        }
                      />
                    )}
                  />
                  <Controller
                    name="password"
                    control={control}
                    rules={{ required: true }}
                    render={({ field, fieldState: { error } }) => (
                      <TextField
                        label="Mot de passe"
                        disabled={loading}
                        type="password"
                        {...field}
                        error={error !== undefined}
                        helperText={
                          error?.type === "required"
                            ? "Champ requis"
                            : error?.message
                        }
                      />
                    )}
                  />
                </Stack>
              </CardContent>
              <CardActions>
                <Box flex={1} />
                <LoadingButton
                  startIcon={<LoginIcon />}
                  type="submit"
                  loading={loading}
                >
                  Connexion
                </LoadingButton>
              </CardActions>
            </form>
          </Card>
        </Box>
      </Stack>
    </Container>
  );
}
