import { Alert, Box, Stack, Typography } from "@mui/material";
import { LoadingCards } from "./LoadingCards";
import { PropsWithChildren } from "react";

export function CardList({
  children,
  loading,
  error,
  emptyText,
}: PropsWithChildren<{
  loading: boolean;
  emptyText: string;
  error?: boolean;
}>) {
  if (loading) {
    return (
      <Box>
        <LoadingCards />
      </Box>
    );
  }

  if (error) {
    return (
      <Box height={200} display={"flex"} alignItems={"center"}>
        <Alert severity="error" sx={{ flex: 1 }}>
          Une erreur est survenue
        </Alert>
      </Box>
    );
  }

  return (
    <Stack direction={"row"} spacing={4} useFlexGap flexWrap={"wrap"}>
      {children !== undefined &&
      Array.isArray(children) &&
      children.length > 0 ? (
        children
      ) : (
        <Box
          height={200}
          alignItems={"center"}
          justifyContent={"center"}
          display={"flex"}
          flex={1}
        >
          <Typography variant="subtitle1" color={"GrayText"}>
            {emptyText}
          </Typography>
        </Box>
      )}
    </Stack>
  );
}
