import {
  Box,
  CardActions,
  CardContent,
  IconButton,
  Stack,
  Typography,
} from "@mui/material";
import RightIcon from "@mui/icons-material/ChevronRight";
import DeleteIcon from "@mui/icons-material/Delete";
import { BaseCard, preventPropagation } from "./BaseCard";

interface DataServiceCardProps {
  name: string;
  data_url: string;
  refresh_prediod: string;
  onOpen?: () => void;
  onDelete?: () => void;
}

export function DataServiceCard({
  name,
  data_url,
  refresh_prediod,
  onOpen,
  onDelete,
}: DataServiceCardProps) {
  return (
    <BaseCard onClick={onOpen}>
      <Stack flex={1} height={"100%"}>
        <Box flex={1}>
          <CardContent>
            <Stack direction={"row"}>
              <Typography
                variant="h5"
                component={"p"}
                fontWeight={"bold"}
                flex={1}
              >
                {name}
              </Typography>
              <Box>
                <IconButton
                  onClick={(e) => {
                    preventPropagation(e);
                    if (onDelete) {
                      onDelete();
                    }
                  }}
                  onMouseDown={preventPropagation}
                >
                  <DeleteIcon />
                </IconButton>
              </Box>
            </Stack>
            <Typography variant="body2">{data_url}</Typography>
            <Typography variant="body2">{refresh_prediod}</Typography>
          </CardContent>
        </Box>
        <CardActions>
          <Box flex={1} />
          <IconButton>
            <RightIcon />
          </IconButton>
        </CardActions>
      </Stack>
    </BaseCard>
  );
}
