import { UnknownEidError, useApiGetDataService } from "@/api/cubicweb";
import { DataService } from "@/types";
import { useState, useEffect } from "react";
import { useHandleAuthErrors } from "./useHandleAuthErrors";

export function useGetDataService(eid: number) {
  const [loading, setLoading] = useState(true);
  const [data, setData] = useState<DataService | undefined>(undefined);
  const [error, setError] = useState<string | undefined>();
  const handleAuthErrors = useHandleAuthErrors();
  const getDataService = useApiGetDataService();

  useEffect(() => {
    setLoading(true);
    setError(undefined);
    if (!isNaN(eid)) {
      getDataService(eid)
        .then((result) => {
          setLoading(false);
          setData(result);
        })
        .catch(handleAuthErrors)
        .catch((e) => {
          if (e instanceof UnknownEidError) {
            setError(`Impossible de trouver le data service '${eid}'`);
          } else {
            setError(`Une erreur inconnue est survenue`);
          }
        });
    }
  }, [eid, handleAuthErrors]);
  return { loading, data, error };
}
