import { useApiUploadDataServiceFile } from "@/api/cubicweb";
import { useState } from "react";
import { useHandleAuthErrors } from "./useHandleAuthErrors";

export function useUploadDataServiceFile() {
  const [loading, setLoading] = useState(false);
  const [error, setError] = useState<string | undefined>();
  const handleAuthErrors = useHandleAuthErrors();
  const uploadDataServiceFile = useApiUploadDataServiceFile();

  async function uploadFile(file: File): Promise<string | null> {
    setLoading(true);
    setError(undefined);
    try {
      const downloadUrl = await uploadDataServiceFile(file);
      setLoading(false);
      return downloadUrl;
    } catch (e) {
      setLoading(false);
      try {
        handleAuthErrors(e);
      } catch {
        setError(`Une erreur inconnue est survenue`);
      }
    }
    return null;
  }
  return { loading, uploadFile, error };
}
